using System;
using System.Collections.Generic;

class Person
{
    public string Name { get; set; }
    public int Age { get; set; }

    public Person(string name, int age)
    {
        Name = name;
        Age = age;
    }

    public override string ToString()
    {
        return $"Name: {Name}, Age: {Age}";
    }
}

class Student : Person
{
    public int Grade { get; set; }

    public Student(string name, int age, int grade) : base(name, age)
    {
        Grade = grade;
    }

    public override string ToString()
    {
        return $"Student: {base.ToString()}, Class: {Grade}";
    }
}

class Teacher : Person
{
    public string Subject { get; set; }

    public Teacher(string name, int age, string subject) : base(name, age)
    {
        Subject = subject;
    }

    public override string ToString()
    {
        return $"Teacher: {base.ToString()}, Subject: {Subject}";
    }
}

class School
{
    public string Name { get; set; }
    public List<Student> Students { get; set; }
    public List<Teacher> Teachers { get; set; }

    public School(string name)
    {
        Name = name;
        Students = new List<Student>();
        Teachers = new List<Teacher>();
    }

    public void AddStudent(string name, int age, int grade)
    {
        Students.Add(new Student(name, age, grade));
    }

    public void AddTeacher(string name, int age, string subject)
    {
        Teachers.Add(new Teacher(name, age, subject));
    }

    public void DisplayInfo()
    {
        Console.WriteLine($"School: {Name}");
        Console.WriteLine("Students:");
        foreach (var student in Students)
        {
            Console.WriteLine(student);
        }
        Console.WriteLine("Teachers:");
        foreach (var teacher in Teachers)
        {
            Console.WriteLine(teacher);
        }
    }
}

class Program
{
    static void Main()
    {
        Console.Write("Enter the name of the school: ");
        string schoolName = Console.ReadLine();
        School school = new School(schoolName);

        while (true)
        {
            Console.WriteLine($"{school.Name}");
            Console.WriteLine("s - Added a student");
            Console.WriteLine("t - Added a teacher");
            Console.WriteLine("v - View information about the school");
            Console.WriteLine("q - Exit");

            string choice = Console.ReadLine();

            switch (choice)
            {
                case "s":
                    Console.Write("Name of the student: ");
                    string studentName = Console.ReadLine();
                    
                    Console.Write("Age of the studenta: ");
                    if (int.TryParse(Console.ReadLine(), out int studentAge))
                    {
                        Console.Write("Student's class: ");
                        if (int.TryParse(Console.ReadLine(), out int studentGrade))
                        {
                            school.AddStudent(studentName, studentAge, studentGrade);
                        }
                        else
                        {
                            Console.WriteLine("False: Invalid age. Тry again.");
                        }
                    }
                    else
                    {
                        Console.WriteLine("False: Invalid class. Тry again.");
                    }
                    break;

                case "t":
                    Console.Write("Teacher's name: ");
                    string teacherName = Console.ReadLine();
                    
                    Console.Write("Age of the teacher: ");
                    if (int.TryParse(Console.ReadLine(), out int teacherAge))
                    {
                        Console.Write("Subject of the teacher: ");
                        string teacherSubject = Console.ReadLine();
                        school.AddTeacher(teacherName, teacherAge, teacherSubject);
                    }
                    else
                    {
                        Console.WriteLine("False: Invalid age. Тry again.");
                    }
                    break;

                case "v":
                    school.DisplayInfo();
                    break;

                case "q":
                    Environment.Exit(0);
                    break;

                default:
                    Console.WriteLine("Wrong option. Тry again.");
                    break;
            }
        }
    }
}

