import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

class Person {
    private String name;
    private int age;

    public Person(String name, int age) {
        this.name = name;
        this.age = age;
    }

    @Override
    public String toString() {
        return "Name: " + name + ", Age: " + age + " years";
    }
}

class Student extends Person {
    private int grade;

    public Student(String name, int age, int grade) {
        super(name, age);
        this.grade = grade;
    }

    @Override
    public String toString() {
        return "Student: " + super.toString() + ", Grade: " + grade;
    }
}

class Teacher extends Person {
    private String subject;

    public Teacher(String name, int age, String subject) {
        super(name, age);
        this.subject = subject;
    }

    @Override
    public String toString() {
        return "Teacher: " + super.toString() + ", Subject: " + subject;
    }
}

class School {
    private String name;
    private List<Student> students;
    private List<Teacher> teachers;

    public School(String name) {
        this.name = name;
        this.students = new ArrayList<>();
        this.teachers = new ArrayList<>();
    }

    public void addStudent(String name, int age, int grade) {
        students.add(new Student(name, age, grade));
    }

    public void addTeacher(String name, int age, String subject) {
        teachers.add(new Teacher(name, age, subject));
    }

    public void displayInfo() {
        System.out.println("School: " + name);
        System.out.println("Students:");
        for (Student student : students) {
            System.out.println(student);
        }
        System.out.println("Teachers:");
        for (Teacher teacher : teachers) {
            System.out.println(teacher);
        }
    }

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        System.out.print("Enter the school name: ");
        String schoolName = scanner.nextLine();
        School school = new School(schoolName);

        while (true) {
            System.out.println(schoolName + " School");
            System.out.println("s - Add student");
            System.out.println("t - Add teacher");
            System.out.println("v - Display school information");
            System.out.println("q - Exit");

            String choice = scanner.nextLine();

            switch (choice) {
                case "s":
                    System.out.print("Student's name: ");
                    String studentName = scanner.nextLine();

                    System.out.print("Student's age: ");
                    int studentAge = Integer.parseInt(scanner.nextLine());

                    System.out.print("Student's grade: ");
                    int studentGrade = Integer.parseInt(scanner.nextLine());

                    school.addStudent(studentName, studentAge, studentGrade);
                    break;

                case "t":
                    System.out.print("Teacher's name: ");
                    String teacherName = scanner.nextLine();

                    System.out.print("Teacher's age: ");
                    int teacherAge = Integer.parseInt(scanner.nextLine());

                    System.out.print("Teacher's subject: ");
                    String teacherSubject = scanner.nextLine();

                    school.addTeacher(teacherName, teacherAge, teacherSubject);
                    break;

                case "v":
                    school.displayInfo();
                    break;

                case "q":
                    System.exit(0);
                    break;

                default:
                    System.out.println("Wrong option. Try again.");
                    break;
            }
        }
    }
}
